var SQLite = {
	/**
	 * 打开数据库，若数据库不存在则创建数据库。
	 * @param {Object} dbName 数据库名字
	 * @param {Object} callback
	 * ret：类型：JSON对象
	 * status:true        //操作成功状态值
	 * err：类型：JSON对象
	 * msg:""    //错误描述
	 */
	openDatabase: function(dbName, callback) {
		var db = api.require('db');
		db.openDatabase({
			name: dbName
		}, function(ret, err) {
			if (typeof callback === 'function') {
				callback(ret, err);
			}
		});
	},
	/**
	 * 关闭数据库
	 * @param {Object} dbName
	 * @param {Object} callback
	 */
	closeDatabase: function(dbName, callback) {
		var db = api.require('db');
		db.closeDatabase({
			name: dbName
		}, function(ret, err) {
			if (typeof callback === 'function') {
				callback(ret, err);
			}
		});
	},
	/**
	 *
	 * @param {Object} dbName
	 * @param {Object} operation
	 * begin //开始事务
	 * commit //提交事务
	 * rollback //回滚操作
	 * @param {Object} callback
	 */
	transaction: function(dbName, operation, callback) {
		var db = api.require('db');
		db.transaction({
			name: dbName,
			operation: operation
		}, function(ret, err) {
			if (typeof callback === 'function') {
				callback(ret, err);
			}
		});
	},
	/**
	 * 执行sql
	 * @param {Object} dbName
	 * @param {Object} sql
	 * @param {Object} callback
	 */
	executeSql: function(dbName, sql, callback) {
		var db = api.require('db');
		db.executeSql({
			name: dbName,
			sql: sql
		}, function(ret, err) {
			if (typeof callback === 'function') {
				callback(ret, err);
			}
		});
	},
	/**
	 *
	 * @param {Object} dbName
	 * @param {Object} sql
	 * @param {Object} callback
	 * ret
	 *    status:true,
	 *    data:[]
	 */
	selectSql: function(dbName, sql, callback) {
		var db = api.require('db');
		db.selectSql({
			name: dbName,
			sql: sql
		}, function(ret, err) {
			if (typeof callback === 'function') {
				callback(ret, err);
			}
		});
	},
	/**
	 * 初始化建表语句
	 */
	init: function(dbName, callback) {
		var that = this;
		that.openDatabase(dbName, function(ret, err) {
			if (ret.status) {
				localStorage.setItem('openDB','Y');
				that.transaction(dbName, 'begin', function(ret, err) {
					if (ret.status) {
						var columnSQL = 'create table if not exists column (id num PRIMARY KEY,code text, name text)';
						that.executeSql(dbName, columnSQL, function(ret, err) {
							if (ret.status) {
								localStorage.setItem('columnTABLE', 'Y');
								that.transaction(dbName, 'commit', function(ret, err) {
									if (ret.status) {
										if (typeof callback === 'function') {
											callback();
										}
									} else {
										alert('rollback===');
										that.transaction(dbName, 'rollback');
									}
								});
							} else {
								alert('executeSql===' + err.msg);
							}
						});
					} else {
						alert('transaction===' + err.msg);
					}
				});
			} else {
				alert('openDatabase===' + err.msg);
			}
		});
	}
};